/*
 * Kosmos.
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package hu.midori.kosmos.portlet;

import javax.portlet.ActionRequest;
import javax.portlet.ActionResponse;
import javax.portlet.GenericPortlet;
import javax.portlet.PortletConfig;
import javax.portlet.PortletException;
import javax.portlet.PortletRequestDispatcher;
import javax.portlet.RenderRequest;
import javax.portlet.RenderResponse;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * Each Kosmos portlet must extend this baseclass.
 *
 * @author <a href="mailto:aron.gombas@midori.hu">Aron Gombas</a>
 * @version $Id$
 */
public abstract class AbstractKosmosPortlet extends GenericPortlet {
    private final static Log log = LogFactory.getLog(AbstractKosmosPortlet.class);

    protected String monitoredResource = null;
    protected String serviceUrl = null;
    
    @Override
    public void init(PortletConfig config) throws PortletException {
        super.init(config);
        
        monitoredResource = config.getInitParameter("monitored.resource");
        serviceUrl = config.getInitParameter("service.url");
        
        if(serviceUrl == null)
            throw new IllegalStateException("'service.url' was not specified in the init-params");
    }
    
    /** Renders a JSP and sets the portlet title. */
    protected void renderJsp(RenderRequest request, RenderResponse response, String jspName, String title) {
        response.setTitle(title);
        renderJsp(request, response, jspName);
    }
    
    /** Renders a JSP. */
    protected void renderJsp(RenderRequest request, RenderResponse response, String jspName) {
        response.setContentType("text/html");
        PortletRequestDispatcher rd = getPortletContext().getRequestDispatcher(jspName);
        try {
            rd.include(request, response);
        } catch(Exception ex) {
            log.error("Unable to include", ex);
        }        
    }

	/** 
	 * This dummy method needs only to make Liferay happy: Liferay will call this when 
	 * minimizing/maximizing the portlet window, and the implementation in <code>GenericPortlet</code> 
	 * simply throws an exception.  
	 */
	@Override
	public void processAction(ActionRequest arg0, ActionResponse arg1) {
		log.debug("Dummy processAction() called");
	}        
}
