/*
 * Kosmos.
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package hu.midori.kosmos.server.sf;

import hu.midori.kosmos.model.SfRelease;
import hu.midori.kosmos.protocol.SfService;
import hu.midori.kosmos.server.AbstractKosmosServiceTest;

import java.util.List;

import org.apache.commons.lang.StringUtils;

/**
 * Unit test.
 *
 * @author <a href="mailto:aron.gombas@midori.hu">Aron Gombas</a>
 * @version $Id$
 */
public class SfServiceTest extends AbstractKosmosServiceTest {
	private SfService service = new SfServiceImpl();
	
	/** Tests with invalid URL. */
	public void testInvalidUrl() {
	    assertEquals(0, service.getFileReleases("http://sourceforge.net/projects/nosuchproject").size());
	}
	
	/** Tests with a project that has no release yet. */
	public void testNoRelease() {
		assertEquals(0, service.getFileReleases("http://sourceforge.net/projects/pixie-perl").size());
	}
	
	public void testKosmosDependencyProjects() {		
		testProjectWithRelease("http://sourceforge.net/projects/cruisecontrol");
		testProjectWithRelease("http://sourceforge.net/projects/displaytag");
		testProjectWithRelease("http://sourceforge.net/projects/jfreechart");
		testProjectWithRelease("http://sourceforge.net/projects/jtidy");
		testProjectWithRelease("http://sourceforge.net/projects/saxon");        
		testProjectWithRelease("http://www.sourceforge.net/projects/springframework");
	}

	public void testJBossProjects() {		
		testProjectWithRelease("http://sourceforge.net/projects/jboss");
	}
	
	public void testKosmosToolProjects() {		
		testProjectWithRelease("http://sourceforge.net/projects/docbook");
		testProjectWithRelease("http://sourceforge.net/projects/junit");
	}
	
	public void testXxx() {
		// TODO test various projects here with long or complicated release list
	}
	
	/** Tests a release. */
	protected void testProjectWithRelease(String url) {
		List<SfRelease> releases = service.getFileReleases(url);
	    assertTrue(releases.size() > 0);		
	    
	    // test releases
	    for(SfRelease release : releases) {
	        assertFalse(StringUtils.isBlank(release.getPackageName()));
	        assertFalse(StringUtils.isBlank(release.getPackageUrl()));
	        assertFalse(StringUtils.isBlank(release.getVersion()));
	        assertFalse(StringUtils.isBlank(release.getVersionUrl()));
	        assertTrue(release.getDate().getTime() > 0);
	        assertTrue(release.getAge() > 0);
	        assertTrue(release.getAgeInDays() > 0);
	    }
	}
}
